@@ -3,8 +3,8 @@ use std::error::Error;
 #[cfg(feature = "ko-dic")]
 fn main() -> Result<(), Box<dyn Error>> {
     use std::env;
-    use std::fs::{create_dir, rename, File};
-    use std::io::{self, Cursor, Read, Write};
+    use std::fs::{create_dir, File};
+    use std::io::{Cursor, Read, Write};
     use std::path::Path;
 
     use encoding::all::UTF_8;
@@ -21,15 +21,9 @@ fn main() -> Result<(), Box<dyn Error>> {
     // Directory path for build package
     let build_dir = env::var_os("OUT_DIR").unwrap(); // ex) target/debug/build/<pkg>/out
 
-    // Dictionary file name
-    let file_name = "mecab-ko-dic-2.1.1-20180720.tar.gz";
-
     // UniDic MeCab directory
     let input_dir = Path::new(&build_dir).join("mecab-ko-dic-2.1.1-20180720");
 
-    // Lindera IPADIC directory
-    let output_dir = Path::new(&build_dir).join("lindera-ko-dic");
-
     if std::env::var("DOCS_RS").is_ok() {
         // Use dummy data in docs.rs.
         create_dir(&input_dir)?;
@@ -51,28 +45,17 @@ fn main() -> Result<(), Box<dyn Error>> {
         let mut dummy_matrix_def = File::create(input_dir.join("matrix.def"))?;
         dummy_matrix_def.write_all(b"0 1 0\n")?;
     } else {
-        // Source file path for build package
-        let source_path_for_build = Path::new(&build_dir).join(&file_name);
+        // Resources directory
+        let resources_dir_path = Path::new("resources");
 
-        // Download source file to build directory
-        if !source_path_for_build.exists() {
-            // copy(&source_path, &source_path_for_build)?;
-            let tmp_path = Path::new(&build_dir).join(file_name.to_owned() + ".download");
+        // Dictionary file name
+        let dict_file_name = "mecab-ko-dic-2.1.1-20180720.tar.gz";
 
-            // Download a tarball
-            let download_url =
-                "https://bitbucket.org/eunjeon/mecab-ko-dic/downloads/mecab-ko-dic-2.1.1-20180720.tar.gz";
-            let resp = ureq::get(download_url).call()?;
-            let mut dest = File::create(&tmp_path)?;
-
-            io::copy(&mut resp.into_reader(), &mut dest)?;
-            dest.flush()?;
-
-            rename(tmp_path, &source_path_for_build).expect("Failed to rename temporary file");
-        }
+        // Source dictionary file path
+        let source_dict_file_path = resources_dir_path.join(dict_file_name);
 
         // Decompress a tarball
-        let mut tar_gz = File::open(&source_path_for_build)?;
+        let mut tar_gz = File::open(&source_dict_file_path)?;
         let mut buffer = Vec::new();
         tar_gz.read_to_end(&mut buffer)?;
         let cursor = Cursor::new(buffer);
@@ -81,6 +64,9 @@ fn main() -> Result<(), Box<dyn Error>> {
         archive.unpack(&build_dir)?;
     }
 
+    // Lindera IPADIC directory
+    let output_dir = Path::new(&build_dir).join("lindera-ko-dic");
+
     // Build a dictionary
     let builder = KoDicBuilder::new();
     builder.build_dictionary(&input_dir, &output_dir)?;
